import subprocess
from abc import ABC


class SysRunner(ABC):
    def __init__(self):
        self.command = None

    @staticmethod
    def __run(command: list):
        return_code = subprocess.call(command)
        return return_code

    def user_run(self):
        return_code = self.__run(self.command)
        return return_code

    def sudo_run(self):
        command = self.command.copy()
        command_str = " ".join(command)
        sh_command = ["sh", "-c", command_str]
        sh_command.insert(0, "/usr/bin/sudo")
        return_code = self.__run(sh_command)
        return return_code



from ideapad_cm.battery.CantReadStatusError import CantReadStatusError
from ideapad_cm.utils.SysEchoToFile import SysEchoToFile


class ConservationMode:
    def __init__(self):
        # TODO: Check if the module ideapad_acpi exists and is loaded
        self.__ideapad_acpi_path = \
            "/sys/bus/platform/drivers/ideapad_acpi/VPC2004:00/conservation_mode"

    def enable(self):
        SysEchoToFile("1", self.__ideapad_acpi_path).sudo_run()

    def disable(self):
        SysEchoToFile("0", self.__ideapad_acpi_path).sudo_run()

    def status(self):
        with open(self.__ideapad_acpi_path, "r") as file:
            returned_status = file.read().replace("\n", "")

        if returned_status == "1":
            return True
        elif returned_status == "0":
            return False
        else:
            raise CantReadStatusError()



#!/usr/bin/env python3

import click

from ideapad_cm.battery.Battery import Battery
from ideapad_cm.battery.CantReadStatusError import CantReadStatusError


@click.group()
def cli():
    pass


@cli.command()
def enable():
    """Enable battery conservation mode."""
    Battery().conservation_mode.enable()


@cli.command()
def disable():
    """Disable battery conservation mode."""
    Battery().conservation_mode.disable()


@cli.command()
def status():
    """Get the status of battery conservation mode."""
    try:
        is_enabled: bool = Battery().conservation_mode.status()
        if is_enabled:
            click.echo("Battery conservation mode is currently enabled.")
        else:
            click.echo("Battery conservation mode is currently disabled.")
    except CantReadStatusError:
        click.echo("Error reading battery conservation mode status.")


cli.add_command(enable)

if __name__ == '__main__':
    # TODO: Make sure the returned exit codes match the original script
    cli()
